Merge ee8179ad2f into 1fe009caed
This commit is contained in:
commit
1dac07623a
|
|
@ -4021,7 +4021,7 @@ static void ggml_cuda_graph_evaluate_and_capture(ggml_backend_cuda_context * cud
|
|||
|
||||
for (int i = 1; i <= concurrent_event->n_streams; ++i) {
|
||||
cudaStream_t stream = cuda_ctx->stream(cuda_ctx->device, i);
|
||||
CUDA_CHECK(cudaStreamWaitEvent(stream, concurrent_event->fork_event));
|
||||
CUDA_CHECK(cudaStreamWaitEvent(stream, concurrent_event->fork_event, 0));
|
||||
}
|
||||
}
|
||||
};
|
||||
|
|
@ -4105,7 +4105,7 @@ static void ggml_cuda_graph_evaluate_and_capture(ggml_backend_cuda_context * cud
|
|||
// Wait on join events of forked streams in the main stream
|
||||
CUDA_CHECK(cudaEventRecord(concurrent_event->join_events[i - 1],
|
||||
cuda_ctx->stream(cuda_ctx->device, i)));
|
||||
CUDA_CHECK(cudaStreamWaitEvent(cuda_ctx->stream(), concurrent_event->join_events[i - 1]));
|
||||
CUDA_CHECK(cudaStreamWaitEvent(cuda_ctx->stream(), concurrent_event->join_events[i - 1], 0));
|
||||
}
|
||||
|
||||
is_concurrent_event_active = false;
|
||||
|
|
|
|||
Loading…
Reference in New Issue